==> ubuntu_localizations-0.1.3.tar.gz: lib/src/l10n/ubuntu_localizations_ko.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Korean (`ko`).
class UbuntuLocalizationsKo extends UbuntuLocalizations {
  UbuntuLocalizationsKo([String locale = 'ko']) : super(locale);

  @override
  String get countryCode => 'KR';

  @override
  String get languageName => '한국어';

  @override
  String get backAction => '뒤로 가기';

  @override
  String get continueAction => '계속하기';

  @override
  String get strongPassword => '강한 암호';

  @override
  String get fairPassword => '양호한 암호';

  @override
  String get goodPassword => '좋은 암호';

  @override
  String get weakPassword => '약한 암호';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => '소개';

  @override
  String get addLabel => '추가';

  @override
  String get allLabel => '모두';

  @override
  String get applyLabel => '적용';

  @override
  String get ascendingLabel => '오름차순';

  @override
  String get backLabel => '뒤로가기';

  @override
  String get boldLabel => '볼드체';

  @override
  String get bottomLabel => '하단';

  @override
  String get cancelLabel => '취소';

  @override
  String get centerLabel => '중앙';

  @override
  String get clearLabel => '지우기';

  @override
  String get closeLabel => '닫기';

  @override
  String get colorLabel => '색상';

  @override
  String get connectLabel => '연결';

  @override
  String get continueLabel => '계속';

  @override
  String get copyLabel => '복사';

  @override
  String get createLabel => '생성';

  @override
  String get cutLabel => '잘라내기';

  @override
  String get decreaseLabel => '감소';

  @override
  String get deleteLabel => '삭제';

  @override
  String get descendingLabel => '내림차순';

  @override
  String get discardLabel => '버리기';

  @override
  String get disconnectLabel => '연결 해제';

  @override
  String get doneLabel => '완료';

  @override
  String get downloadLabel => '내려받기';

  @override
  String get editLabel => '수정';

  @override
  String get enterLabel => '입력';

  @override
  String get errorLabel => '오류';

  @override
  String get executeLabel => '실행';

  @override
  String get exitLabel => '종료';

  @override
  String get fileLabel => '파일';

  @override
  String get fillLabel => '채우기';

  @override
  String get findLabel => '찾기';

  @override
  String get firstLabel => '처음';

  @override
  String get fontLabel => '폰트';

  @override
  String get forwardLabel => '앞으로';

  @override
  String get fullscreenLabel => '전체 화면';

  @override
  String get goBackLabel => '뒤로';

  @override
  String get helpLabel => '도움';

  @override
  String get homeLabel => '홈';

  @override
  String get importLabel => '불러오기';

  @override
  String get increaseLabel => '증가';

  @override
  String get indexLabel => '색인';

  @override
  String get informationLabel => '정보';

  @override
  String get insertLabel => '삽입';

  @override
  String get italicLabel => '이탈릭체';

  @override
  String get landscapeLabel => '랜드스케이프';

  @override
  String get lastLabel => '마지막';

  @override
  String get leaveLabel => '나가기';

  @override
  String get leftLabel => '좌측';

  @override
  String get mediaLabel => '미디어';

  @override
  String get networkLabel => '네트워크';

  @override
  String get newLabel => '신규';

  @override
  String get nextLabel => '다음';

  @override
  String get noLabel => '아니요';

  @override
  String get noneLabel => 'None';

  @override
  String get normalLabel => '보통';

  @override
  String get okLabel => '확인';

  @override
  String get openLabel => '열기';

  @override
  String get pasteLabel => '붙여넣기';

  @override
  String get pauseLabel => '중지';

  @override
  String get playLabel => '재생';

  @override
  String get portraitLabel => '포트레이트';

  @override
  String get preferencesLabel => '환경 설정';

  @override
  String get previousLabel => '이전';

  @override
  String get printLabel => '인쇄';

  @override
  String get printPreviewLabel => '인쇄 미리보기';

  @override
  String get propertiesLabel => '속성';

  @override
  String get questionLabel => '질문';

  @override
  String get quitLabel => '종료';

  @override
  String get recordLabel => '기록';

  @override
  String get redoLabel => '돌리기';

  @override
  String get refreshLabel => '새로고침';

  @override
  String get removeLabel => '삭제';

  @override
  String get renameLabel => '이름 변경';

  @override
  String get resetLabel => '초기화';

  @override
  String get restoreLabel => '복구';

  @override
  String get retryLabel => '다시시도';

  @override
  String get revertLabel => '복구';

  @override
  String get rewindLabel => '되감기';

  @override
  String get rightLabel => '우측';

  @override
  String get saveAsLabel => '다른 이름으로 저장';

  @override
  String get saveLabel => '저장';

  @override
  String get searchLabel => '검색';

  @override
  String get selectAllLabel => '모두 선택';

  @override
  String get selectLabel => '선택';

  @override
  String get sendLabel => '전송';

  @override
  String get skipLabel => '넘기기';

  @override
  String get sortLabel => '정렬';

  @override
  String get stopLabel => '중단';

  @override
  String get strikeThroughLabel => '취소선';

  @override
  String get submitLabel => '제출';

  @override
  String get topLabel => '상위';

  @override
  String get undoLabel => '되돌리기';

  @override
  String get updateLabel => '갱신';

  @override
  String get upLabel => '위로';

  @override
  String get viewLabel => '보기';

  @override
  String get warningLabel => '경고';

  @override
  String get windowLabel => '윈도우';

  @override
  String get yesLabel => '예';

  @override
  String get zoomInLabel => '확대';

  @override
  String get zoomOutLabel => '축소';
}

==> ubuntu_localizations-0.2.1.tar.gz: lib/src/l10n/ubuntu_localizations_ko.dart <==
import 'ubuntu_localizations.dart';

/// The translations for Korean (`ko`).
class UbuntuLocalizationsKo extends UbuntuLocalizations {
  UbuntuLocalizationsKo([String locale = 'ko']) : super(locale);

  @override
  String get countryCode => 'KR';

  @override
  String get languageName => '한국어';

  @override
  String get backAction => '뒤로 가기';

  @override
  String get continueAction => '계속하기';

  @override
  String get strongPassword => '강한 암호';

  @override
  String get fairPassword => '양호한 암호';

  @override
  String get goodPassword => '좋은 암호';

  @override
  String get weakPassword => '약한 암호';

  @override
  String get altKey => 'Alt';

  @override
  String get controlKey => 'Control';

  @override
  String get metaKey => 'Meta';

  @override
  String get shiftKey => 'Shift';

  @override
  String get aboutLabel => '소개';

  @override
  String get addLabel => '추가';

  @override
  String get allLabel => '모두';

  @override
  String get applyLabel => '적용';

  @override
  String get ascendingLabel => '오름차순';

  @override
  String get backLabel => '뒤로가기';

  @override
  String get boldLabel => '볼드체';

  @override
  String get bottomLabel => '하단';

  @override
  String get cancelLabel => '취소';

  @override
  String get centerLabel => '중앙';

  @override
  String get clearLabel => '지우기';

  @override
  String get closeLabel => '닫기';

  @override
  String get colorLabel => '색상';

  @override
  String get connectLabel => '연결';

  @override
  String get continueLabel => '계속';

  @override
  String get copyLabel => '복사';

  @override
  String get createLabel => '생성';

  @override
  String get cutLabel => '잘라내기';

  @override
  String get decreaseLabel => '감소';

  @override
  String get deleteLabel => '삭제';

  @override
  String get descendingLabel => '내림차순';

  @override
  String get discardLabel => '버리기';

  @override
  String get disconnectLabel => '연결 해제';

  @override
  String get doneLabel => '완료';

  @override
  String get downloadLabel => '내려받기';

  @override
  String get editLabel => '수정';

  @override
  String get enterLabel => '입력';

  @override
  String get errorLabel => '오류';

  @override
  String get executeLabel => '실행';

  @override
  String get exitLabel => '종료';

  @override
  String get fileLabel => '파일';

  @override
  String get fillLabel => '채우기';

  @override
  String get findLabel => '찾기';

  @override
  String get firstLabel => '처음';

  @override
  String get fontLabel => '폰트';

  @override
  String get forwardLabel => '앞으로';

  @override
  String get fullscreenLabel => '전체 화면';

  @override
  String get goBackLabel => '뒤로';

  @override
  String get helpLabel => '도움';

  @override
  String get homeLabel => '홈';

  @override
  String get importLabel => '불러오기';

  @override
  String get increaseLabel => '증가';

  @override
  String get indexLabel => '색인';

  @override
  String get informationLabel => '정보';

  @override
  String get insertLabel => '삽입';

  @override
  String get italicLabel => '이탈릭체';

  @override
  String get landscapeLabel => '랜드스케이프';

  @override
  String get lastLabel => '마지막';

  @override
  String get leaveLabel => '나가기';

  @override
  String get leftLabel => '좌측';

  @override
  String get mediaLabel => '미디어';

  @override
  String get networkLabel => '네트워크';

  @override
  String get newLabel => '신규';

  @override
  String get nextLabel => '다음';

  @override
  String get noLabel => '아니오';

  @override
  String get noneLabel => 'None';

  @override
  String get normalLabel => '보통';

  @override
  String get okLabel => '확인';

  @override
  String get openLabel => '열기';

  @override
  String get pasteLabel => '붙여넣기';

  @override
  String get pauseLabel => '중지';

  @override
  String get playLabel => '재생';

  @override
  String get portraitLabel => '포트레이트';

  @override
  String get preferencesLabel => '환경 설정';

  @override
  String get previousLabel => '이전';

  @override
  String get printLabel => '인쇄';

  @override
  String get printPreviewLabel => '인쇄 미리보기';

  @override
  String get propertiesLabel => '속성';

  @override
  String get questionLabel => '질문';

  @override
  String get quitLabel => '종료';

  @override
  String get recordLabel => '기록';

  @override
  String get redoLabel => '돌리기';

  @override
  String get refreshLabel => '새로고침';

  @override
  String get removeLabel => '삭제';

  @override
  String get renameLabel => '이름 변경';

  @override
  String get resetLabel => '초기화';

  @override
  String get restoreLabel => '복구';

  @override
  String get retryLabel => '다시시도';

  @override
  String get revertLabel => '복구';

  @override
  String get rewindLabel => '되감기';

  @override
  String get rightLabel => '우측';

  @override
  String get saveAsLabel => '다른 이름으로 저장';

  @override
  String get saveLabel => '저장';

  @override
  String get searchLabel => '검색';

  @override
  String get selectAllLabel => '모두 선택';

  @override
  String get selectLabel => '선택';

  @override
  String get sendLabel => '전송';

  @override
  String get skipLabel => '넘기기';

  @override
  String get sortLabel => '정렬';

  @override
  String get stopLabel => '중단';

  @override
  String get strikeThroughLabel => '취소선';

  @override
  String get submitLabel => '제출';

  @override
  String get topLabel => '상위';

  @override
  String get undoLabel => '되돌리기';

  @override
  String get updateLabel => '갱신';

  @override
  String get upLabel => '위로';

  @override
  String get viewLabel => '보기';

  @override
  String get warningLabel => '경고';

  @override
  String get windowLabel => '윈도우';

  @override
  String get yesLabel => '예';

  @override
  String get zoomInLabel => '확대';

  @override
  String get zoomOutLabel => '축소';
}
